@@ -47,6 +47,12 @@ Loads the Base64-encoded key from the specified file.
 
 Loads the Base64-encoded key from a string already in memory.
 
+  my $key3 = Mail::DKIM::PrivateKey->load(Cork => $openssl_object);
+
+Creates a Mail::DKIM::PrivateKey wrapper object for the given
+OpenSSL key object. The key object should be of type
+L<Crypt::OpenSSL::RSA>.
+
 =cut
 
 sub load
@@ -71,6 +77,8 @@ sub load
 			push @data, $_;
 		}
 		$self->{'DATA'} = join '', @data;
+	} elsif ($prms{'Cork'}) {
+		$self->{'CORK'} = $prms{'Cork'};
 	} else {
 		croak "missing required argument";
 	}
@@ -78,6 +86,16 @@ sub load
 	return $self;
 }
 
+=head1 METHODS
+
+=head2 cork() - access the underlying OpenSSL key object
+
+  $openssl_object = $key->cork;
+
+The returned object is of type L<Crypt::OpenSSL::RSA>.
+
+=cut
+
 sub convert {
 	use Crypt::OpenSSL::RSA;
 
@@ -120,6 +138,7 @@ sub convert {
 	return 1;
 }
 
+#deprecated
 sub sign
 {
 	my $self = shift;
@@ -129,6 +148,7 @@ sub sign
 	return $self->cork->sign($mail);
 }
 
+#deprecated- use sign_digest() instead
 sub sign_sha1_digest
 {
 	my $self = shift;
@@ -136,6 +156,20 @@ sub sign_sha1_digest
 	return $self->sign_digest("SHA-1", $digest);
 }
 
+=head2 sign_digest()
+
+Cryptographically sign the given message digest.
+
+  $key->sign_digest("SHA-1", sha1("my message text"));
+
+The first parameter is the name of the digest: one of "SHA-1", "SHA-256".
+
+The second parameter is the message digest as a binary string.
+
+The result should be the signed digest as a binary string.
+
+=cut
+
 sub sign_digest
 {
 	my $self = shift;
@@ -149,4 +183,18 @@ sub sign_digest
 	return $rsa_priv->decrypt($EM);
 }
 
+=head1 AUTHOR
+
+Jason Long, E<lt>jlong@messiah.eduE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2006-2008 by Messiah College
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
+
 1;
