@@ -721,12 +721,20 @@ sub identity_matches
 	return lc($addr) eq lc($id);
 }
 
-=head2 key() - get or set the key object
+=head2 key() - get or set the private key object
 
   my $key = $signature->key;
 
   $signature->key(Mail::DKIM::PrivateKey->load(File => "private.key"));
 
+The private key is used for signing messages.
+It is not used for verifying messages.
+
+The key object can be any object that implements the
+L<sign_digest()|Mail::DKIM::PrivateKey/"sign_digest()"> method.
+(Providing your own object can be useful if your actual keys
+are stored out-of-process.)
+
 =cut
 
 sub key
